@@ -55,33 +55,46 @@ typedef enum {
 } MsgMode;
 
 typedef struct {
-  gchar	*dialog_text;
+  gchar   *dialog_text;
   MsgMode  mode;
+  gboolean no_wrap;
 } ZenityMsgData;
 
 typedef struct {
-  gchar	*uri;
+  gchar   *dialog_text;
+  gint     value;
+  gint     min_value;
+  gint     max_value;
+  gint     step;
+  gboolean print_partial;
+  gboolean hide_value;
+} ZenityScaleData;
+
+typedef struct {
+  gchar	  *uri;
   gboolean multi;
-  gchar *separator;
+  gboolean directory;
+  gboolean save;
+  gchar   *separator;
 } ZenityFileData;
 
 typedef struct {
-  gchar	       *dialog_text;
-  gchar	       *entry_text;
-  gboolean      visible;
+  gchar   *dialog_text;
+  gchar   *entry_text;
+  gboolean hide_text;
 } ZenityEntryData;
 
 typedef struct {
-  gchar        *dialog_text;
-  gchar        *entry_text;
-  gboolean      pulsate;
-  gboolean	autoclose;
-  gdouble       percentage;
+  gchar   *dialog_text;
+  gchar   *entry_text;
+  gboolean pulsate;
+  gboolean autoclose;
+  gdouble  percentage;
 } ZenityProgressData;
 
 typedef struct {
   gchar         *uri;
-  gboolean      editable;
+  gboolean       editable;
   GtkTextBuffer	*buffer;
 } ZenityTextData;
 
@@ -91,11 +104,18 @@ typedef struct {
   gboolean      checkbox;
   gboolean      radiobox;
   gchar        *separator;
+  gboolean      multi;
   gboolean      editable;
   gchar	       *print_column;
+  gchar	       *hide_column;
   const gchar **data;
 } ZenityTreeData;
 
+typedef struct {
+  gchar   *notification_text;
+  gboolean listen;
+} ZenityNotificationData;
+
 void    zenity_calendar         (ZenityData             *data,
                                 ZenityCalendarData      *calendar_data);
 void    zenity_msg              (ZenityData             *data,
@@ -110,6 +130,10 @@ void    zenity_text             (ZenityData             *data,
                                  ZenityTextData         *text_data);
 void    zenity_tree             (ZenityData             *data,
                                  ZenityTreeData         *tree_data);
+void	zenity_notification	(ZenityData		*data,
+				 ZenityNotificationData	*notification_data);
+void	zenity_scale		(ZenityData		*data,
+				 ZenityScaleData	*scale_data);
 void    zenity_about            (ZenityData             *data);
 
 G_END_DECLS
